@@ -43,7 +43,7 @@ class ResourcePluginLoader(PluginLoader):
             #if we've reached this point, there's no subclass of Plugin in the file!
             raise PluginLoadError("a file for '{0}' exists, but there is no plugin in it".format(name))
         except Exception:
-            raise PluginLoadError("'{0}'' failed to load".format(name), sys.exc_info())
+            raise PluginLoadError("'{0}' failed to load".format(name), sys.exc_info())
 
     def find_plugins(self):
         for f in pkg_resources.resource_listdir('mk2', self.search_path):
@@ -84,7 +84,49 @@ class EntryPointPluginLoader(PluginLoader):
             yield ep.name
 
 
+class _PluginProperty(object):
+    def __init__(self, default=None, type_=False, required=False):
+        self.default = default
+        self.required = required
+
+        self.type = default.__class__ if (default is not None and type_ is False) else type_
+
+    def coerce(self, value):
+        if self.type is False or isinstance(value, self.type):
+            return value
+        return self.type(value)
+
+    def __get__(self, instance, owner):
+        if instance is None:
+            return self
+        return instance._args.get(self, self.default)
+
+    def __set__(self, instance, value):
+        instance._args[self] = self.coerce(value)
+
+
+class PluginMetaclass(type):
+    def __init__(cls, name, bases, dict_):
+        cls._contains = [n for n, v in inspect.getmembers(cls)
+                         if isinstance(v, _PluginProperty)]
+        cls._requires = [n for n in cls._contains if getattr(cls, n).required]
+
+        for b in bases:
+            if hasattr(b, '_contains'):
+                cls._contains.extend(b._contains)
+            if hasattr(b, '_requires'):
+                cls._requires.extend(b._requires)
+
+        return type.__init__(cls, name, bases, dict)
+
+
 class Plugin:
+    __metaclass__ = PluginMetaclass
+
+    Property = _PluginProperty
+
+    enabled = Property()
+
     restore = tuple()
 
     def __init__(self, parent, name, **kwargs):
@@ -101,9 +143,23 @@ class Plugin:
         self._tasks = []
         self._events = []
         self._services = []
-    
-        for n, v in kwargs.iteritems():
-            setattr(self, n, v)
+
+        self._args = {}
+
+        missing = set(self._requires) - set(kwargs.iterkeys())
+        excess = set(kwargs.iterkeys()) - set(self._contains)
+        if missing:
+            raise Exception("Plugin {0} missing properties: {1}".
+                            format(self.__class__.__name__, ", ".join(missing)))
+        elif excess:
+            raise Exception("Plugin {0} got extraneous properties: {1}".
+                            format(self.__class__.__name__, ", ".join(excess)))
+        for k, v in kwargs.iteritems():
+            try:
+                setattr(self, k, v)
+            except TypeError:
+                expected_type = getattr(self.__class__, k).type.__name__
+                raise Exception("{0!r} is invalid for {1}.{2} which expects type {3}".format(v, self.__class__.__name__, k, expected_type))
         
         self.register(self.server_started, ServerStarted)
         self.register(self.server_stopping, ServerStopping)
@@ -147,10 +203,10 @@ class Plugin:
             self.unregister(ident)
     
     def save_state(self):
-        return [getattr(self, k) for k in self.restore]
+        return dict((k, getattr(self, k)) for k in self.restore)
 
     def load_state(self, state):
-        [setattr(self, k, state.pop(0)) for k in self.restore]
+        [setattr(self, k, v) for k, v in state.iteritems()]
     
     def delayed_task(self, callback, delay, name=None):
         hook = self._task(callback, name)
@@ -162,12 +218,12 @@ class Plugin:
     def repeating_task(self, callback, interval, name=None, now=False):
         hook = self._task(callback, name)
         t = self.parent.events.dispatch_repeating(hook, interval, now=now)
-        t._stop    = t.stop
+        t._stop = t.stop
         t._active = lambda: t.running
         self._tasks.append(t)
     
     def _task(self, callback, name=None):
-        if name == None:
+        if name is None:
             name = id(callback)
         hook = Hook(name=name)
         self.parent.events.register(callback, Hook, name=name)
@@ -264,7 +320,10 @@ class PluginManager(dict):
                     continue
 
                 #instantiate plugin
-                plugin = cls(self.parent, name, **kwargs)
+                try:
+                    plugin = cls(self.parent, name, **kwargs)
+                except Exception:
+                    raise PluginLoadError("'{0}' failed to initialize".format(name), sys.exc_info())
 
                 #restore state
                 if name in self.states:
