@@ -1,5 +1,5 @@
-from plugins import Plugin
-from events import ServerEvent, EventPriority
+from mk2.plugins import Plugin
+from mk2.events import ServerEvent, EventPriority
 
 from twisted.internet import reactor
 from twisted.internet.defer import Deferred, DeferredList
@@ -74,6 +74,28 @@ class HTTPEndpoint(Endpoint):
         self.wait(defer)
 
 
+@endpoint("http")
+class UserHTTPEndpoint(HTTPEndpoint):
+    method = "POST"
+
+    def __init__(self, plugin, url):
+        self.endpoint = "{scheme}://{url}".format(self.scheme, url)
+
+    def setup(self, event):
+        self.postdata = {
+            "server":      plugin.parent.server_name,
+            "priority":    event.priority,
+            "event":       event.friendly,
+            "cause":       event.cause,
+            "description": event.data
+        }
+
+
+@endpoint("https")
+class UserHTTPSEndpoint(UserHTTPEndpoint):
+    pass
+
+
 @endpoint("nma")
 class NMAEndpoint(HTTPEndpoint):
     endpoint = "https://www.notifymyandroid.com/publicapi/notify"
@@ -179,15 +201,15 @@ class SMTPEndpoint(Endpoint):
 
 
 class Push(Plugin):
-    endpoints           = ""
+    endpoints           = Plugin.Property(default="")
 
-    email_address       = "mark2@fantastic.minecraft.server"
-    email_smtp_server   = ""
-    email_smtp_user     = ""
-    email_smtp_password = ""
-    email_smtp_security = False
+    email_address       = Plugin.Property(default="mark2@fantastic.minecraft.server")
+    email_smtp_server   = Plugin.Property(default="")
+    email_smtp_user     = Plugin.Property(default="")
+    email_smtp_password = Plugin.Property(default="")
+    email_smtp_security = Plugin.Property(default=False)
 
-    pushover_token      = ""
+    pushover_token      = Plugin.Property(default="")
     
     def setup(self):
         global _plugin
